# Glotter

[![Build Status](https://travis-ci.org/auroq/glotter.svg?branch=master)](https://travis-ci.org/auroq/glotter)

Glotter is an execution library for collections of single file scripts. It uses Docker to be able to build, run, and optionally test scripts in any language without having to install a local sdk or development environment.

For getting started with Glotter, refer to our [wiki](https://github.com/auroq/glotter/wiki)

## Contributing

If you'd like to contribute to Glotter, read our [contributing guidelines](./CONTRIBUTING.md).
